@@ -2,7 +2,7 @@
 
 ## classify_test_data_in_a_file_numeric.pl
 
-#use lib '../blib/lib', '../blib/arch';
+use lib '../blib/lib', '../blib/arch';
 
 use strict;
 use Algorithm::DecisionTree;
