@@ -1,8 +1,8 @@
 #!/usr/bin/perl -w
 
-## generate_training_and_test_data_numeric.pl
+use lib '../blib/lib', '../blib/arch';
 
-#use lib '../blib/lib', '../blib/arch';
+##  generate_training_and_test_data_numeric.pl
 
 use strict;
 use Algorithm::DecisionTree;
